$set 3 #Configmenu

$ #ConfigOptions
# Indstillinger
$ #FocusModel
# Fokus Model
$ #WindowPlacement
# Vindueplacering
$ #ImageDithering
# Billede Dithering
$ #OpaqueMove
# Uklar vinduesflytning
$ #FullMax
# Fuld maximering
$ #FocusNew
# Fokus nyt vindue
$ #FocusLast
# Fokus vindue ved skrivebords ndring
$ #ClickToFocus
# Klik for fokus
$ #SloppyFocus
# Dovent fokus
$ #AutoRaise
# Hv automatisk
$ #SmartRows
# Intelligent placering (Rkker)
$ #SmartCols
# Intelligent placering (Sjler)
$ #Cascade
# Kaskade placering
$ #LeftRight
# Fra venstre mod hjre
$ #RightLeft
# Fra hjre mod venstre
$ #TopBottom
# Oppefra
$ #BottomTop
# Nedefra
$ #Tabs
# Use Tabs
$ #Icons
# Use Icons
$ #TabRotateVertical
# Rotate Vertical Tabs
$ #SemiSloppyFocus
# Semi Sloppy Focus
$ #MaxOverSlit
# Maximize Over Slit
$ #SloppyWindowGrouping
# Sloppy Window Grouping
$ #WorkspaceWarping
# Workspace Warping
